import Vue from 'vue'

import Cookies from 'js-cookie'

import 'normalize.css/normalize.css' // a modern alternative to CSS resets

import Element from 'element-ui'
import './assets/styles/element-variables.scss'

import '@/assets/styles/index.scss' // global css
import '@/assets/styles/ruoyi.scss' // ruoyi css
import App from './App'
import store from './store'
import router from './router'
import permission from './directive/permission'

import './assets/icons' // icon
import './permission' // permission control
import { getDicts } from '@/api/system/dict/data'
import { getConfigKey } from '@/api/system/config'
import { parseTime, resetForm, addDateRange, selectDictLabel } from '@/utils/ruoyi'
import Pagination from '@/components/Pagination'
/**
 * 表单设计
 */
import EleForm from 'vue-ele-form'
import EleFormUploadFile from 'vue-ele-form-upload-file'
import EleFormImageUploader from 'vue-ele-form-image-uploader'

import VJsoneditor from 'v-jsoneditor'


import axios from 'axios'

axios.interceptors.response.use(response => {
  let data = response.data
  console.log(data)
  // 将响应结果返回
  return data;
})
Vue.prototype.$axios = axios



// 全局方法挂载
Vue.prototype.getDicts = getDicts
Vue.prototype.getConfigKey = getConfigKey
Vue.prototype.parseTime = parseTime
Vue.prototype.resetForm = resetForm
Vue.prototype.addDateRange = addDateRange
Vue.prototype.selectDictLabel = selectDictLabel

Vue.prototype.msgSuccess = function(msg) {
  this.$message({ showClose: true, message: msg, type: 'success' })
}

Vue.prototype.msgError = function(msg) {
  this.$message({ showClose: true, message: msg, type: 'error' })
}

Vue.prototype.msgInfo = function(msg) {
  this.$message.info(msg)
}

// 全局组件挂载
Vue.component('Pagination', Pagination)
Vue.use(permission)

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online! ! !
 */

Vue.use(Element, {
  size: Cookies.get('size') || 'medium' // set element-ui default size
})

Vue.use(VJsoneditor)

Vue.component('VJsoneditor', VJsoneditor)


// 注册 image-uploader 组件
Vue.component('image-uploader', EleFormImageUploader)
// 注册 upload-file 组件
Vue.component('upload-file', EleFormUploadFile)

// 注册 ele-form
Vue.use(EleForm, {
  //图片上传设置
  upload: {
    action: 'http://actservice.hw.hongweisoft.com/prod-api/common/upload', // 请求地址,
    responseFn(response, file) {
      if (response.code === 500) {
        this.$message({ showClose: true, message: response.msg, type: 'error' })
        return false;
      }else{
        return response.url
      }
    }
  },
  //文件上传设置
  'upload-file': {
    // 上传地址
    action: 'http://actservice.hw.hongweisoft.com/prod-api/common/uploadac',
    responseFn(response, file) {
      if (response.code === 500) {
        this.$message({ showClose: true, message: response.msg, type: 'error' })
        return false;
      }else{
        return {
          name: file.name,
          url: response.url,
          size: file.size
        }
      }
    }
  }
})

Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
